adproclus-class: An S4 class to represent an ADPROCLUS solution.

Description Slots

Description

An S4 class to represent an ADPROCLUS solution.

Slots

clusters

A length-one numeric vector denoting the number of clusters in the solution

Model

A model matrix M of the same size as the input data matrix.

Membs

The n*k membership matrix of the clustering model

Profs

The k*j profile matrix of the clustering model

sse

A numeric denoting the residual sum of squares of the clustering model

totvar

A numeric denoting the total sum of squares of the input data matrix

explvar

A numeric denoting the proportion of variance in data that is accounted for by the clustering model.

alg_iter

A numeric denoing the number of iterations of the ALS algorithm

timer

A numeric denoting the elapsed time in seconds to obtain the clustering solution

initialStart

A list containing information about the stat used to initialize the algorithm


JRBCH/ADPROCLUS documentation built on Oct. 30, 2019, 7:33 p.m.