getRational: Generate initial rational start

Description Usage Arguments Details Value References See Also Examples

View source: R/main.R

Description

Generate an initial rational start for the Additive Profile Clustering algorithm (see adproclus).

Usage

1
getRational(data, centers)

Arguments

data

Object-by-variable data matrix of class matrix or data.frame.

centers

either the number of clusters k, or a matrix of initial (distinct) cluster centres.

Details

If centers is a number of clusters k, an initial profile matrix P is generated by drawing k randomly chosen, distinct, rows from data. Alternatively, you can pass a user selected matrix of size k * ncol(data) with initial cluster profiles to the centers argument. In both cases, a corresponding membership matrix A is subsequently estimated conditionally upon P (for details, see Depril et al., 2008, and Wilderjans et al., 2010).

Warning: This function does not obtain an ADPRCOLUS model. To perform aditive profile clustering, see adproclus.

Value

getRational returns a list with the following components:

type

A character string denoting the type of start ('Rational Start')

A

An initial Membership matrix

P

The corresponding initial Profile matrix

References

Wilderjans, T. F., Ceulemans, E., Van Mechelen, I., & Depril, D. (2010). ADPROCLUS: a graphical user interface for fitting additive profile clustering models to object by variable data matrices. Behavior Research Methods, 43(1), 56-65.

Depril, D., Van Mechelen, I., & Mirkin, B. (2008). Algorithms for additive clustering of rectangular data tables. Computational Statistics and Data Analysis, 52, 4923-4938.

See Also

getRandom for generating random starts and adproclus for details about membership and profile matrices.

Examples

1
getRational(ADPROCLUS::CGdata, 3)

JRBCH/ADPROCLUS documentation built on Oct. 30, 2019, 7:33 p.m.