An S4 class to represent an ADPROCLUS solution.
clustersA length-one numeric vector denoting the number of clusters in the solution
ModelA model matrix M of the same size as the input data matrix.
MembsThe n*k membership matrix of the clustering model
ProfsThe k*j profile matrix of the clustering model
sseA numeric denoting the residual sum of squares of the clustering model
totvarA numeric denoting the total sum of squares of the input data matrix
explvarA numeric denoting the proportion of variance in data that is accounted for by the clustering model.
alg_iterA numeric denoing the number of iterations of the ALS algorithm
timerA numeric denoting the elapsed time in seconds to obtain the clustering solution
initialStartA list containing information about the stat used to initialize the algorithm
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.