Description Usage Arguments Details Value References See Also Examples
Generate an initial rational start for the Additive Profile Clustering
algorithm (see adproclus).
1 | getRational(data, centers)
|
data |
Object-by-variable data matrix of class |
centers |
either the number of clusters k, or a matrix of initial (distinct) cluster centres. |
If centers is a number of clusters k, an initial profile matrix
P is generated by drawing k randomly chosen, distinct, rows
from data. Alternatively, you can pass a user selected matrix of size
k * ncol(data) with initial cluster profiles to the
centers argument. In both cases, a corresponding membership matrix
A is subsequently estimated conditionally upon P (for
details, see Depril et al., 2008, and Wilderjans et al., 2010).
Warning: This function does not obtain an ADPRCOLUS model. To
perform aditive profile clustering, see adproclus.
getRational returns a list with the following components:
typeA character string denoting the type of start ('Rational Start')
AAn initial Membership matrix
PThe corresponding initial Profile matrix
Wilderjans, T. F., Ceulemans, E., Van Mechelen, I., & Depril, D. (2010). ADPROCLUS: a graphical user interface for fitting additive profile clustering models to object by variable data matrices. Behavior Research Methods, 43(1), 56-65.
Depril, D., Van Mechelen, I., & Mirkin, B. (2008). Algorithms for additive clustering of rectangular data tables. Computational Statistics and Data Analysis, 52, 4923-4938.
getRandom for generating random starts and
adproclus for details about membership and profile matrices.
1 | getRational(ADPROCLUS::CGdata, 3)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.